@@ -32,13 +32,13 @@
  *          
  * \date
  *          - created: 2005/11/11
- *          - last changed: \$Date: 2006/02/14 10:27:33 $
+ *          - last changed: \$Date: 2006/04/05 12:11:58 $
  * 
  * \note    This file is part of the tool BPEL2oWFN and was created during the
  *          project "Tools4BPEL" at the Humboldt-Universitt zu Berlin. See
  *          http://www.informatik.hu-berlin.de/top/tools4bpel for details.
  *
- * \version \$Revision: 1.46 $
+ * \version \$Revision: 1.48 $
  */
 
 
@@ -46,8 +46,11 @@
 
 
 #include "helpers.h"
-#include "check-symbols.h"
-#include "bpel-attributes.h"
+#include "options.h"
+#include "debug.h"
+#include "petrinet.h"
+// #include "check-symbols.h"
+// #include "bpel-attributes.h"
 
 
 
@@ -78,10 +81,6 @@ set<Node *> setUnion(set<Node *> a, set<Node *> b)
   return result;
 }
 
-
-
-
-
 /*!
  * \param i standard C int
  * \return  C++ string representing i
