@@ -28,17 +28,17 @@
  * 
  * \author  
  *          - responsible: Niels Lohmann <nlohmann@informatik.hu-berlin.de>
- *          - last changes by: \$Author: nlohmann $
+ *          - last changes by: \$Author: gierds $
  *          
  * \date    
  *          - created: 2005/11/11
- *          - last changed: \$Date: 2006/02/09 19:09:06 $
+ *          - last changed: \$Date: 2006/04/05 12:11:58 $
  * 
  * \note    This file is part of the tool BPEL2oWFN and was created during the
  *          project "Tools4BPEL" at the Humboldt-Universitt zu Berlin. See
  *          http://www.informatik.hu-berlin.de/top/tools4bpel for details.
  *
- * \version \$Revision: 1.24 $
+ * \version \$Revision: 1.27 $
  */
 
 
@@ -58,11 +58,10 @@
 
 #include <set>
 #include <string>
-#include "petrinet.h"
+// #include "petrinet.h"
 #include "exception.h"	// exception handling
-#include "check-symbols.h"
+// #include "check-symbols.h"
 #include "bpel2owfn.h"
-#include "options.h"
 
 using namespace std;
 
@@ -76,6 +75,70 @@ class Node;
 /// Returns the union of two sets of Petri net nodes.
 set<Node *> setUnion(set<Node *> a, set<Node *> b);
 
+/**
+ * Returns the union of two sets of T's.
+ *
+ * \par a the first set
+ * \par b the second set
+ * \returns the set of a united with b (a \\/ b)
+ */
+template <class T>
+set<T> setUnion(set<T> & a, set<T> & b)
+{
+  set<T> resultSet;
+  resultSet.insert(a.begin(), a.end());
+  resultSet.insert(b.begin(), b.end());
+
+  return resultSet;
+}
+
+/**
+ * Returns the intersection of two sets of T's.
+ *
+ * \par a the first set
+ * \par b the second set
+ * \returns the set of a intersected with b (a /\\ b)
+ */
+template <class T>
+set<T> setIntersection(set<T> & a, set<T> & b)
+{
+  std::set<T> resultSet;
+  if (! (a.empty() || b.empty()))
+  {
+    for (typename set<T>::iterator iter = a.begin(); iter != a.end(); iter++)
+    {
+      if (b.find(*iter) != b.end())
+      {
+	resultSet.insert(*iter);
+      }
+    }
+  }
+
+  return resultSet;
+}
+
+/**
+ * Returns the difference of two sets of T's.
+ *
+ * \par a the first set
+ * \par b the second set
+ * \returns the set of a minus b (a \\ b)
+ */
+template <class T>
+set<T> setDifference(set<T> & a, set<T> & b)
+{
+  set<T> resultSet (a);
+  if (! (a.empty() || b.empty()))
+  {
+    for (typename set<T>::iterator iter = b.begin(); iter != b.end(); iter++)
+    {
+      resultSet.erase(*iter);
+    }
+  }
+
+  return resultSet;
+}
+
 /// Converts int to string.
 string intToString(int i);
 
@@ -89,7 +152,7 @@ void print_help();
 void print_version(std::string name);
 
 /// Evaluates command line arguments
-void parse_command_line(int argc, char * argv[]);
+// void parse_command_line(int argc, char * argv[]);
 
 /// Calls #cleanup(), then exits
 void error();
