@@ -28,18 +28,18 @@
  * 
  * \author  
  *          - responsible: Christian Gierds <gierds@informatik.hu-berlin.de>
- *          - last changes of: \$Author: nlohmann $
+ *          - last changes of: \$Author: gierds $
  *          
  * \date
  *          - created: 2005/10/18
- *          - last changed: \$Date: 2006/02/16 15:09:11 $
+ *          - last changed: \$Date: 2006/03/31 14:56:53 $
  * 
  * \note    This file is part of the tool BPEL2oWFN and was created during the
  *          project "Tools4BPEL" at the Humboldt-Universitt zu Berlin. See
  *          http://www.informatik.hu-berlin.de/top/forschung/projekte/tools4bpel
  *          for details.
  *
- * \version \$Revision: 1.59 $
+ * \version \$Revision: 1.66 $
  *          - 2005-11-15 (gierds) Moved command line evaluation to helpers.cc.
  *            Added option to created (abstracted) low level nets.
  *            Added option for LoLA output.
@@ -53,6 +53,8 @@
 
 #include "main.h"
 #include "options.h"
+#include "ast-printers.h"
+
 
 /// The Petri Net
 PetriNet *TheNet = new PetriNet();
@@ -90,7 +92,6 @@ int main( int argc, char *argv[])
     {
       trace(TRACE_INFORMATION, "Parsing complete.\n");
       
-      symMan.printScope();
       if (modus == M_AST)
       {
 	trace(TRACE_INFORMATION, "-> Printing AST ...\n");
@@ -121,6 +122,14 @@ int main( int argc, char *argv[])
         trace(TRACE_INFORMATION, "-> Unparsing AST to CFG ...\n");
         TheProcess->unparse(kc::pseudoPrinter, kc::cfg);
 	// do some business with CFG
+	list<kc::integer> kcl;
+	TheCFG->needsDPE(0, kcl);
+	TheCFG->resetProcessedFlag();
+
+	/// \todo (gierds) check for cyclic links, otherwise we will fail
+	// test
+	TheCFG->checkForUninitializedVariables();
+	/// end test
       }
 
       if (modus == M_CFG)
@@ -133,7 +142,7 @@ int main( int argc, char *argv[])
 	  }
  	  trace(TRACE_INFORMATION, "-> Printing CFG in dot ...\n");
           // output CFG;
-  	  TheCFG->print_dot();
+  	  cfgDot(TheCFG);
 	  if (output_filename != "")
 	  {
 	    closeOutput(output);
@@ -153,10 +162,13 @@ int main( int argc, char *argv[])
         trace(TRACE_INFORMATION, "-> Unparsing AST to Petri net ...\n");
         TheProcess->unparse(kc::pseudoPrinter, kc::petrinet);
 
-	// remove isolated nodes
-	TheNet->removeIsolatedNodes();
-	
-        // simplify net ?
+        // remove variables?
+ 	if ( parameters[P_NOVARIABLES] )
+        {
+ 	  trace(TRACE_INFORMATION, "-> Remove variable places from Petri Net ...\n");
+          TheNet->removeVariables();
+        }    
+	// simplify net ?
  	if ( parameters[P_SIMPLIFY] )
         {
  	  trace(TRACE_INFORMATION, "-> Structurally simplifying Petri Net ...\n");
