@@ -42,15 +42,21 @@ typedef enum
 
 typedef enum
 {
-  P_SIMPLIFY,		// structural reduction rules
-  P_FINISHLOOP,		// live-lock "well-formed" systems
-  P_NOSTANDARDFAULTS,	// only user-defined faults can occur
-  P_CYCLICWHILE		// use the original <while> pattern
+  P_SIMPLIFY,		///< structural reduction rules
+  P_FINALLOOP,		///< live-lock "well-formed" systems
+  P_NOSTANDARDFAULTS,	///< only user-defined faults can occur
+  P_CYCLICWHILE,	///< use the original <while> pattern
+  P_CYCLICEH,		///< use the original <eventHandlers> pattern
+  P_NOFHFAULTS,		///< activities inside the FH throw no faults
+  P_NOVARIABLES		///< removes all variables from the model
 } possibleParameters;
 
 
 // some file names and pointers (in options.cc)
 
+extern void parse_command_line(int argc, char* argv[]);
+
+
 /// Filename of input file
 extern std::string filename;
 /// Filename of input file
